#!/bin/sh
#
# File:		TWSPLUSinstall_after.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#
MODULE_VERSION=;export MODULE_VERSION

#
#	The standard directory and the /Plus override script
#
ETC=/etc/Tivoli
SCRIPT=PLUSsetup_env.sh

#
#	If this is NT, then etc is in a different location
#
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     ETC=$SystemRoot/system32/drivers/etc/Tivoli
fi

#
#	Look for our override script, if not there, then use the
#		standard one.
#
if [ ! -f $ETC/$SCRIPT ]; then
	SCRIPT=setup_env.sh
fi

. $ETC/$SCRIPT


#
#	Set up some popular environment variables.
#
OSERV=`objcall 0.0.0 get_oserv`
export OSERV
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
REGION=`objcall $OSERV query whoami | awk '{print $1}'`

LIBRARY=`wlookup Library`

#
#	Get the region name to avoid collisions
#
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

DEFSEN=\"TivoliSentryDefaults#$IRONAME\"

MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`
export MNNAME

#
#       Process winstall variables 
#
ALL=false; REGION_ONLY=false; UNDO=false; COPY_FILES_ONLY=false; UNDO_INFRA=false
DO_JOBS=false; DO_FILEPACKS=false; DO_SENTRIES=false

if [ ${UNINSTALL:=0} -eq 1 ]; then
  UNDO=true
  UNINSTALL_OPTS=""
fi

## cue off DOTASKS from winstall being either "0" or "1" to know
## if we're in incremental install mode ...
if [ "$DOTASKS" ]; then
  INCREMENTAL_INSTALL=true
  if [ $DOALL -eq 1 ]; then
    ALL=true
    UNINSTALL_OPTS="a"
  fi
else
  INCREMENTAL_INSTALL=false
  ALL=true
fi

if [ "$ALL" = false ]; then
  if [ $DOTASKS -eq 1 ]; then
    DO_JOBS=true
    UNINSTALL_OPTS="j${UNINSTALL_OPTS}"
  fi
  if [ $DOMONS -eq 1 ]; then
    DO_SENTRIES=true
    UNINSTALL_OPTS="s${UNINSTALL_OPTS}"
  fi
  if [ $DOFPS -eq 1 ]; then
    DO_FILEPACKS=true
    UNINSTALL_OPTS="f${UNINSTALL_OPTS}"
  fi
fi

export INCREMENTAL_INSTALL ALL DO_JOBS DO_SENTRIES DO_FILEPACKS UNDO

PLUSDIR=$INST_DIR/generic_unix/TME/PLUS
LINKDIR=$PLUSDIR/LINK
PRODDIR=$PLUSDIR/TWS
PATH=$LINKDIR:$PRODDIR:$PATH
export PATH

cd $PRODDIR

. ./PLUSproduct-info.sh

#
#	This setting controls the task library creation behavior
#
USE_TLL=true; export USE_TLL

#
#	This setting determines if TMA (LCF endpoints) are supported in this install)
#
TMA_ENABLED=true
if wlookup -ar Gateway > /dev/null 2>& 1; then
  :
else
  echo "Dataless endpoints are not supported by this version of Tivoli" >& 2
  TMA_ENABLED=false
fi
export TMA_ENABLED

#
#       Use the MODULE setting to determine the patch id (for uninstall)
#
PATCH_ID=TWSPLUS; export PATCH_ID

#
#	Use the module-level TaskRoles setting to set up a default ROLE for tasks
#
DEFAULT_TASKROLES=super; export DEFAULT_TASKROLES

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts is
#		redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
	TEMP=$DBDIR/tmp
else
	TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug

SCRIPTNAME=`echo $0 | tr "\\\\\\\\" "/"`
SCRIPTNAME=`basename $SCRIPTNAME`

[ -d "$DEBUGDIR" ] && exec > $DEBUGDIR/$SCRIPTNAME && DEBUG=true && set -xv
[ -f "$DEBUGDIR" ] && DEBUG=true && set -xv

chmod +x $LINKDIR/Link.install $LINKDIR/Link.init $LINKDIR/Link.cfg $LINKDIR/w* $LINKDIR/cfgappicon $LINKDIR/faux* $LINKDIR/*.sh
if $UNDO; then
  ## use existing undo interface to PLUSinstruct.sh ...
  $LINKDIR/PLUSinstruct.sh -ud${UNINSTALL_OPTS} ./PLUSproduct-info.sh

else
  ## do install
  . $LINKDIR/PLUSinstall.sh

  ###########################################################################
  #
  #  at this point the plus module has been installed.
  #  insert any code to run after installation here.
  #

  #
  # add global attributes
  #
  for installopt in $INSTALL_OPTS; do
  	eval OPT='"$'$installopt'"'
  	eval OPTVAL='"$'$OPT'"'
  	eval OPTNAME='"$'$installopt'_NAME"'
  
  	# create a hidden presentation object to hold the install options
  	PRESNAME="$OPTNAME"
  
  	# see if it's already created
  	if wlookup -r Presentation "$PRESNAME" > /dev/null 2>& 1; then
  	    log_info "Presentation Object '$PRESNAME' already exists"
  	else
  
  	    MNOID=`objcall 0.0.0 get_host_location`
  	    PRESOBJ=`idlcall $CO \
  	                TMF_SysAdmin::InstanceManager::create_instance \
  			OBJECT_NIL $MNOID \"$PRESNAME\"`
  	    initpres "$PRESNAME" -pres-name -create
  	fi
  
  	# if the attribute doesn't exist, add it, otherwise set it.
  	if wgetattr $OPT @Presentation:"$PRESNAME" > /dev/null 2>& 1; then
  	    wsetattr "$OPTVAL" $OPT @Presentation:"$PRESNAME"
  	else
  	    waddattr -v "$OPTVAL" $OPT @Presentation:"$PRESNAME"
  	fi
  done

  #
  # add local environment file tws_plus.sh
  #
  ETC=/etc/Tivoli
  if [ x\"$OS\" = x\"Windows_NT\" ] ; then
    ETC=$SystemRoot/system32/drivers/etc/Tivoli
  fi

  TWS_PLUS_SH="tws_plus.sh"
  echo "MAESTROUSER=$TWSUSER" > "$ETC/$TWS_PLUS_SH"
  echo "MAESTRODIR=\"$TWSDIR\"" >> "$ETC/$TWS_PLUS_SH"
  echo "JSCONSOLEDIR=\"$JSCONSOLEDIR\"" >> "$ETC/$TWS_PLUS_SH"
  echo "export MAESTROUSER MAESTRODIR JSCONSOLEDIR" >> "$ETC/$TWS_PLUS_SH"



  #
  # convert to dataless profile managers
  #

  if [ "$TMA_ENABLED" = true ]; then
    #
    # subscription lists
    #
    sublists="SUBLIST_PM_1 SUBLIST_PM_2"
    for sb in $sublists ;do
        eval mae_sb='"$'$sb'"'
        maestro_prfmgr=`wls -l /Library/ProfileManager | grep "$mae_sb"`
        maestro_prfmgr_id=`echo $maestro_prfmgr| awk -F"#" '{ print $1 '}`
        #wregister -r ProfileManager "$mae_sb" $maestro_prfmgr_id
        wsetpm -d @ProfileManager:"$mae_sb#$IRONAME"
    done

    #
    # filepacks
    #
    if $COURIER_INSTALLED ; then
        filepacks="FILEPACK_1 FILEPACK_2 FILEPACK_3"
        for fp in $filepacks ;do
            eval mae_fp='"$'$fp'"'
            maestro_prfmgr=`wls -l /Library/ProfileManager | grep "$mae_fp"`
            maestro_prfmgr_id=`echo $maestro_prfmgr| awk -F"#" '{ print $1 '}`
#            wregister -r ProfileManager "$mae_fp" $maestro_prfmgr_id
            wsetpm -d @ProfileManager:"$mae_fp#$IRONAME"
        done
    fi

    #
    # sentry progile manager
    #
    if $SENTRY_INSTALLED ; then
        monitors="SENTRY_PM_1"
        for mon in $monitors ;do
            eval mae_mon='"$'$mon'"'
            maestro_prfmgr=`wls -l /Library/ProfileManager | grep "$mae_mon"`
            maestro_prfmgr_id=`echo $maestro_prfmgr| awk -F"#" '{ print $1 '}`
#            wregister -r ProfileManager "$mae_mon" $maestro_prfmgr_id
            wsetpm -d @ProfileManager:"$mae_mon#$IRONAME"
        done
    fi

  fi



fi

#
# Downloading TWS .fmt files to the existing ManagedNodes
#

  REGION=`objcall 0.0.0 self | awk -F. '{print $1}'`

  TMR_MN=`wlookup -ar ManagedNode | grep $REGION.1 | awk '{print $2}'`
  TMR_OSERV=`objcall $TMR_MN get_oserv`
  TMR_BINDIR=`objcall $TMR_OSERV query install_dir | tr "\\\\\\\\" "/"` 
  TPLUS_DIR="$TMR_BINDIR/generic_unix/TME/PLUS/TWS"

  echo "TMR_MN=$TMR_MN" > mn.tmp
  echo "export TMR_MN" >> mn.tmp
  echo "REGION=$REGION" >> mn.tmp
  echo "export REGION" >> mn.tmp
  echo "TMR_OSERV=$TMR_OSERV" >> mn.tmp
  echo "export TMR_OSERV" >> mn.tmp
  echo "TMR_BINDIR=$TMR_BINDIR" >> mn.tmp
  echo "export TMR_BINDIR" >> mn.tmp
  echo "TPLUS_DIR=$TPLUS_DIR" >> mn.tmp
  echo "export TPLUS_DIR" >> mn.tmp


  wlookup -ar ManagedNode | awk '{ print "MN_OSERV\=\`objcall "$2" get_oserv\`\nMN_BINDIR\=\`objcall $MN_OSERV query install_dir \| tr \"\\\\\\\\\\\\\\\\\" \"\/\"\`\nTPLUS_MN_DIR\=\"$MN_BINDIR\/generic_unix\/TME\/PLUS\/TWS\"\n\`idlcall $TMR_MN files_transfer FALSE "$2" \\\"$TPLUS_DIR\\\" \\\"$TPLUS_MN_DIR\\\" \\\{ 1 \\\"maestro.fmt\\\" \\\}\`\n\`idlcall $TMR_MN files_transfer FALSE "$2" \\\"$TPLUS_DIR\\\" \\\"$TPLUS_MN_DIR\\\" \\\{ 1 \\\"maestront.fmt\\\" \\\}\`" }' >> mn.tmp
  #echo "exit 0" >> mn.tmp
  . ./mn.tmp
  rm -rf mn.tmp

exit 0
