#!/bin/sh
#
# File: 	check_tec_server.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#

###
#
#   errecho
#
errecho() {
  echo "$*" >&2
}

###
#
# is_lcf_ep
#
is_lcf_ep() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -z "$ENDPOINT_OID" ]; then
    return 1
  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
    # found a "+" in the oid, must be a TMA endpoint!
    return 0
  else
    return 1
  fi
}

###
#
# cr_TP_dep
#
cr_TP_dep() {

  if wlookup -ar DependencyMgr | grep "^TPlusAdapter" >/dev/null 2>&1
  then
        TPdep=`wlookup -ar DependencyMgr | grep "^TPlusAdapter" | awk '{ print $2 }' | awk -F\# '{ print $1 }'`				>/dev/null 2>&1
	wdepset -d @DependencyMgr:TPlusAdapter
  fi

  dep=`wlookup -ar DependencyMgr | grep task-spawn32 | awk '{ print $2 }' | awk -F\# '{ print $1 }'`
  curroid=`echo $dep | awk -F. '{ print $3 }'`
  deplist=`wlookup -ar DependencyMgr -o`
  while [ ! -z "$dep" ]
  do
	dependency=$dep
	dep="" 
	for var in $deplist; do
		if wdepset -v $var | grep "$dependency"						>/dev/null 2>&1
		then
			var2=`echo $var | awk -F# '{ print $1 }'`
			if [ ! -z $var2 ]; then
				var=$var2
			fi
			oid=`echo $var | awk -F. '{ print $3 }'`
			if [ $oid -gt $curroid ]; then
				curroid=$oid
				dep=$var
			fi
		fi
		if [ ! -z "$TPdep" ]; then
                	if wdepset -v $var | grep "$TPdep"						>/dev/null 2>&1
                	then
                  	      wdepset -e $var -r depset "$TPdep"
               	 	fi
		fi
	done
  done

  wdepset -c TPlusAdapter -a generic ../generic_unix/TME/PLUS/TWS/maestro.fmt +p PLUS +a\
			-a w32-ix86 ../generic_unix/TME/PLUS/TWS/maestront.fmt +p PLUS +a\
			-a w32-ix86 bin/w32-ix86/endpoint/wlocpath.exe +p PLUS +a\
			-a solaris2 bin/solaris2/endpoint/wlocpath +p PLUS +a\
			-a hpux10 bin/hpux10/endpoint/wlocpath +p PLUS +a\
			-a sunos4 bin/sunos4/endpoint/wlocpath +p PLUS +a\
			-a aix4-r1 bin/aix4-r1/endpoint/wlocpath +p PLUS +a
  wdepset -e `wchdep -g @Classes:TaskEndpoint run_task` -a depset @DependencyMgr:TPlusAdapter
  wlookup -ar Gateway | awk '{ print "wgateway "$1" dbcheck" }' > gateway.tmp
  gateway.tmp
  rm -f gateway.tmp
}

########################################################################

if [ -n "" ]; then
	DEBUG=true
fi
[ "$DEBUG" = true ] && set -x

TASK_PROGPATH=`echo $0 | sed -e 's.\\\\./.g'`
THIS_SCRIPT="check_tec_server.sh"

#
#	Make sure we're running on a Managed Node
#
if is_lcf_ep; then
  errecho "Cannot run $THIS_SCRIPT: endpoint $ENDPOINT_OID is not a ManagedNode"
  exit 1
fi

#
#	The standard directory and the (optional) /Plus override script
#
ETC=/etc/Tivoli
SETUP_SCRIPT=""

#
#	If this is NT, then etc is in a different location
#
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     ETC=$SystemRoot/system32/drivers/etc/Tivoli
fi

#
#	Look for our override script, if not there, then use the
#		standard one.
#
if [ ! -f "$ETC/$SETUP_SCRIPT" ]; then
	SETUP_SCRIPT=setup_env.sh
fi

. $ETC/$SETUP_SCRIPT


#
#	Set up some popular environment variables.
#
OSERV=`objcall 0.0.0 get_oserv`
export OSERV
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
REGION=`objcall $OSERV query whoami | awk '{print $1}'`

LIBRARY=`wlookup Library`

#
#	Get the region name to avoid collisions
#
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`
export MNNAME

PLUSDIR=$INST_DIR/generic_unix/TME/PLUS
LINKDIR=$PLUSDIR/LINK
PRODDIR=$PLUSDIR/TWS
PATH=$LINKDIR:$PRODDIR:$PATH
export PATH

cd $PRODDIR

#. ./PLUSproduct-info.sh

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts is
#		redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
	TEMP=$DBDIR/tmp
else
	TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug
[ -d "$DEBUGDIR" ] && exec > $DEBUGDIR/$THIS_SCRIPT 2>&1 && set -xv
[ -f "$DEBUGDIR" ] && set -xv

STATUS=0

echo "*** Executing $THIS_SCRIPT"

THIS_HOST_INDEX=`objcall 0.0.0 self | awk -F. '{print \$2}'`
TEC_SERVER_INDEX=`wlookup -r EventServer "EventServer#$IRONAME" | awk -F. '{print \$2}'`
if [ x"$THIS_HOST_INDEX" = x"$TEC_SERVER_INDEX" ] ; then
	STATUS=0
else
	STATUS=1
fi


#
# If this is a TEC Server create the dependency to download TWS-TEC files
#
if [ $STATUS -eq 0 ]; then
	cr_TP_dep
fi

echo "*** Exiting $THIS_SCRIPT ($TASK_PROGPATH) with return code $STATUS"

exit $STATUS
