#!/bin/sh
#
# File: 	config_tec.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#
unset CHILD_OF_OSERV
###
#
#   errecho
#
errecho() {
  echo "$*" >&2
}

###
#
# is_lcf_ep
#
is_lcf_ep() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -z "$ENDPOINT_OID" ]; then
    return 1
  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
    # found a "+" in the oid, must be a TMA endpoint!
    return 0
  else
    return 1
  fi
}

###
#
# get_tec_version
#
get_tec_version()
{
	TEC=`wlookup -r ProductInfo TEC_SERVER 2>/dev/null`
	TEC_REVISION=`idlattr -t -g $TEC revision string 2>/dev/null | sed 's/"//g'`
	if ( expr $TEC_REVISION \= 3.7 >/dev/null && wlookup -ar PatchInfo | \
                 grep "3.7-TEC-0008" >/dev/null ) || \
           expr $TEC_REVISION \> 3.7 >/dev/null
    	then
		 tecver="TEC37+"
    	elif expr $TEC_REVISION \= 3.7 >/dev/null
	then
		 tecver="TEC37-"
	else
		 tecver="TEC36"
    	fi
    	eval echo "$tecver"
}


########################################################################

if [ -n "" ]; then
	DEBUG=true
fi
[ "$DEBUG" = true ] && set -x

TASK_PROGPATH=`echo $0 | sed -e 's.\\\\./.g'`
THIS_SCRIPT="config_tec.sh"

#
#	Make sure we're running on a Managed Node
#
if is_lcf_ep; then
  errecho "Cannot run $THIS_SCRIPT: endpoint $ENDPOINT_OID is not a ManagedNode"
  exit 1
fi

#
#	The standard directory and the /Plus override script
#
ETC=/etc/Tivoli
SCRIPT=PLUSsetup_env.sh

#
#	If this is NT, then etc is in a different location
#
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     ETC=$SystemRoot/system32/drivers/etc/Tivoli
fi

#
#	Look for our override script, if not there, then use the
#		standard one.
#
if [ ! -f $ETC/$SCRIPT ]; then
	SCRIPT=setup_env.sh
fi

. $ETC/$SCRIPT


#
#	Set up some popular environment variables.
#
OSERV=`objcall 0.0.0 get_oserv`
export OSERV
INST_DIR=`objcall $OSERV query install_dir`
INST_DIR=`echo $INST_DIR | tr "\\\\\\\\" "/"`
export INST_DIR
REGION=`objcall $OSERV query whoami | awk '{print $1}'`

LIBRARY=`wlookup Library`

#
#	Get the region name to avoid collisions
#
IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

DEFSEN=\"TivoliSentryDefaults#$IRONAME\"

MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`
export MNNAME

PLUSDIR=$INST_DIR/generic_unix/TME/PLUS
LINKDIR=$PLUSDIR/LINK
PRODDIR=$PLUSDIR/TWS
PATH=$LINKDIR:$PRODDIR:$PATH
export PATH

cd $PRODDIR

. ./PLUSproduct-info.sh

TEC_VERSION=`get_tec_version`
export WINSTRUCTED
export MODULE_VERSION

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts is
#		redirected to a file in TEMP by the same name as the script.
#
TEMP=/tmp
if [ x"$OS" = x"Windows_NT" ]; then
	TEMP=$DBDIR/tmp
else
	TEMP=/tmp
fi

DEBUGDIR=$TEMP/.plusdebug
[ -d "$DEBUGDIR" ] \
  && echo "*** Results redirected to $DEBUGDIR/$THIS_SCRIPT" \
  && exec > $DEBUGDIR/$THIS_SCRIPT 2>&1 && set -xv
[ -f "$DEBUGDIR" ] && set -xv
if [ -d "$DEBUGDIR" -o -f "$DEBUGDIR" -o "$DEBUG" = true ]; then
  DEBUG=true
else
  DEBUG=false
fi
export DEBUG

#
#	Messages
#
SOURCE_NAME=PLUSTASKS

###################
# Support Functions
###################

errexit()
{
	echo "$*" >&2
	exit 1
}

if expr $TEC_VERSION \= "TEC37-" >/dev/null \
         || expr $TEC_VERSION \= "TEC36" >/dev/null
then
	. $LINKDIR/PLUScommon-tec-install.sh
else
	. common-tec-install.sh
fi

echo "*** Executing $THIS_SCRIPT ($TASK_PROGPATH)"

###################
# Process Arguments
###################

##
##	Usage Check
##
#ARGLIST="Rule_Base_Name__new_or_existing__ Rule_Base_to_clone__if_new__ Path_for_Rule_Base__if_new__ Name_of_Event_Console_to_configure__optional__"
#
#if [ $# -ne `echo $ARGLIST | wc -w` ]; then
#	errexit "Usage: $THIS_SCRIPT $ARGLIST"
#fi
#
#RB_NAME=$1
#RB_TO_CLONE=$2
#RB_PATH=$3
#EV_CONSOLE=$4
#
#if [ ! "$RB_NAME" ]; then
#	errexit "$ERRNORULEBASE"
#fi
#
##UseNew=$1
##UseExisting=$2
##ExistingRulebase=$3
##NewRulebase=$4
##CloneRulebase=$5
##RulebasePath=$6
##EventConsole=$7
#
##
##  Map arguments to some standard variable names
##
#if [ "$RB_TO_CLONE" ]; then
#  UseNew=on
#  NewRulebase="$RB_NAME"
#  CloneRulebase="$RB_TO_CLONE"
#else
#  UseExisting=on
#  ExistingRulebase="$RB_NAME"
#fi
#RulebasePath="$RB_PATH"
#EventConsole="$EV_CONSOLE"

if [ $# -ne 10 ]; then
     errecho   "Usage: $0 UseNew UseExisting ExistingRulebase NewRulebase CloneRulebase RulebasePath EventConsole" "$0"
     exit 1
fi

UseNew=$1
UseExisting=$2
ExistingRulebase=$3
NewRulebase=$4
CloneRulebase=$5
RulebasePath=$6
EventConsole=$7
TECUIServer=$8
USER=$9
shift
PASSWORD=$9

if is_OS_NT; then
	wrb_cmd="perl $BINDIR/bin/wrb"
else
	wrb_cmd="$BINDIR/bin/wrb"
fi


if   [ "$UseNew" = on ]; then
	Rulebase=$NewRulebase
	if expr $TEC_VERSION \= "TEC37-" >/dev/null \
         || expr $TEC_VERSION \= "TEC36" >/dev/null
	then
	    if wlsrb "^${Rulebase}$" > /dev/null 2>&1 ;then
		errecho "There is an existing '${Rulebase}' rule base."
		exit 1
	    fi
	else
	    if  $wrb_cmd -lsrb "^${Rulebase}$" > /dev/null 2>&1 ;then
		errecho "There is an existing '${Rulebase}' rule base."
		exit 1
	    fi
	fi
elif [ "$UseExisting" = on ]; then
	Rulebase=$ExistingRulebase
	if expr $TEC_VERSION \= "TEC37-" >/dev/null \
         || expr $TEC_VERSION \= "TEC36" >/dev/null
	then
	    if wlsrb "^${Rulebase}$" >/dev/null 2>&1 ;then
		echo "Found rule base '${Rulebase}'"
	    else
		errecho "The rule base '${Rulebase}' does not exist."
		exit 1
	    fi
	else
	    if  $wrb_cmd -lsrb "^${Rulebase}$" > /dev/null 2>&1 ;then
		echo "Found rule base '${Rulebase}'"
	    else
		errecho "The rule base '${Rulebase}' does not exist."
		exit 1
	    fi
	fi
else
	errecho "You must specify either a new or an existing rule base."
	exit 1
fi

Sources="Source2 Source3 Source4"
#Source1="$SOURCE_NAME"  Source1Bitmap="JLINK"
Source2="SENTRY"	Source2Bitmap="sentry48"
Source3="LOGFILE"	Source3Bitmap="logf48"
Source4="NT"		Source4Bitmap="s_nt48"

#Filter1="-c Sentry2_0 -s SENTRY"
#Filter2="-c ${SHORT_Prodname}_Base -s $SOURCE_NAME"
if expr $TEC_VERSION \= "TEC37-" >/dev/null \
        || expr $TEC_VERSION \= "TEC36" >/dev/null
then
	Filter3="-c TWS_Base -s LOGFILE"
	Filter4="-c TWS_Monitors -s SENTRY"
	Filter5="-c TWS_NT_Base -s NT"
else
	Filter3="TWS_Base_LOGFILE_flt TWS_% LOGFILE"
	Filter4="TWS_Monitors_SENTRY_flt TWS_Monitors SENTRY"
	Filter5="TWS_NT_Base_NT_flt TWS_NT% NT"	
fi

Filters="Filter3 Filter4 Filter5"

#PlusRules="$LINKDIR/tivoli_plus.rls"
RulesFiles="$PlusRules"
for f in $TEC_RULE_FILES; do
	eval RULE_FILE='"$'$f'"'
	RulesFiles="$RULE_FILE $RulesFiles"
done
	
for f in $TEC_RULE_TGTS; do
	eval RULE_TGT='"$'$f'"'
	RulesFilesTgt="$RULE_TGT $RulesFilesTgt"
done

for f in $TEC_BAROC_FILES; do
	eval BAROC_FILE='"$'$f'"'
	ClassFiles="$ClassFiles $BAROC_FILE"
done
ClassIfPresent="${SHORT_Prodname}Base"

DM_VERSION=3_5

DM_MAJOR=`echo $DM_VERS | awk -F. '{print $1}' | awk -F_ '{print $1}'`
DM_MINOR=`echo $DM_VERS | awk -F. '{print $2}' | awk -F_ '{print $2}'`
if [ ! "$DM_MAJOR" ]; then
  DM_MAJOR=3; DM_MINOR=5
elif [ ! "$DM_MINOR" ]; then
  DM_MAJOR=3; DM_MINOR=5
fi
### Avoid referring to a DM version, but if needed you could do the next 3 statements:
#DM_CLASS=Sentry${DM_MAJOR}_${DM_MINOR}
#DM_BASE_CLASS=${DM_CLASS}_Base
#DM_MON_BAROC_FILE=Sentry${DM_MAJOR}.${DM_MINOR}Monitors.baroc

DM_CLASS=DM_Extension
DM_CLASS_BASE=${DM_CLASS}_Base
DM_MON_BAROC_FILES=""

baroc_files="
  Sentry.baroc
  Sentry2.0Monitors.baroc
  Sentry3.5Monitors.baroc
"
for f1 in $DM_MON_BAROC_FILES; do
  new=true
  for f2 in $baroc_files; do
    if [ "$f1" = "$f2" ]; then
      new=false
      break
    fi
  done 
  if $new; then
    baroc_files="$baroc_files $f1"
  fi
done

# class checked to determine if $SentryClassFiles needs to be installed
#SentryClassFile=$DM_CLASS_BASE     
SentryClassFile=Sentry2_0

# baroc files installed if $SentryClassFile doesn't exist
SentryClassFiles="`echo ${baroc_files}`"
###SentryClassFiles="${LINKDIR}/Sentry.baroc ${LINKDIR}/${DM_MON_BAROC_FILE}"

LocalClassPath=$BINDIR/../generic/SentryMonitors
TMRClassPath=`get_tme_server_SentryMonitors_path`
LinkClassPath=$LINKDIR
ProdClassPath=$PRODDIR

### Modify this if desired:
ClassPathSearchOrder="$ProdClassPath $TMRClassPath $LocalClassPath $LinkClassPath"

EventGroup="TWSPlus"

verify_rule_base
if $CreateNewRulebase; then
	echo Creating new rulebase $Rulebase
	verify_clone_rule_base
	VerificationRB=$CloneRulebase
else
	echo $Rulebase already exists
	VerificationRB=$Rulebase
fi

if expr $TEC_VERSION \= "TEC37+" >/dev/null \
         || expr $TEC_VERSION \= "TEC36" >/dev/null
then
	verify_event_console
fi

verify_sentry_classes
verify_current_rule_base_compiles

if $CreateNewRulebase; then
	create_new_rule_base
	clone_rule_base
	verify_new_rule_base_compiles
fi

import_new_classes

$PreDeletePlusRules && delete_plus_rules
import_new_rules

verify_new_rule_base_compiles

load_new_rules

install_new_event_source
if expr $TEC_VERSION \= "TEC37+" >/dev/null \
         || expr $TEC_VERSION \= "TEC36" >/dev/null
then
	install_new_event_group
	install_new_event_filters
fi

#
# Start - Section
#
# the following has been copied from PLUScommon-tec-install.sh to work
# around problem adding filters with sub-source.
if expr $TEC_VERSION \= "TEC36" >/dev/null
then
    if waddegflt -c Sentry2_0_Base -s SENTRY -u "TWS Remote Monitors" $EventGroup
    then
	echo "Added event filter -c Sentry2_0_Base -s SENTRY -u \"TWS Remote Monitors\" $EventGroup"
    else
	errecho "Failed adding event filter -c Sentry2_0 -s SENTRY -u \"TWS Remote Monitors\" $EventGroup"
    fi
elif expr $TEC_VERSION \= "TEC37+" >/dev/null
then
    if is_OS_NT; then
	   wconsole_cmd="wconsole.cmd"
    else
	   wconsole_cmd="wconsole"
    fi
    if $wconsole_cmd -addegflt -h $TECUIServer -u $USER -p $PASSWORD -E $EventGroup -n TWS_Remote_Monitors_flt -s "(class='Sentry2_0_Base') AND (source='SENTRY') AND (sub_source='TWS Remote Monitors')"
    then
	echo "Added event filter -c Sentry2_0_Base -s SENTRY -u \"TWS Remote Monitors\" $EventGroup"
    else
	errecho "Failed adding event filter -c Sentry2_0 -s SENTRY -u \"TWS Remote Monitors\" $EventGroup"
    fi
fi

#
# End - Section
#

if expr $TEC_VERSION \= "TEC37+" >/dev/null \
         || expr $TEC_VERSION \= "TEC36" >/dev/null
then
	assign_event_group_to_console
fi

if expr $TEC_VERSION \= "TEC36" >/dev/null
then
    install_trouble_ticket_script
fi

restart_event_server
