#!/bin/sh
#
# File:		jsconsole.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#

###
#
#   errecho
#
errecho() {
  echo "$*" >&2
}

###
#
# is_lcf_ep
#
is_lcf_ep() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -z "$ENDPOINT_OID" ]; then
    return 1
  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
    # found a "+" in the oid, must be a TMA endpoint!
    return 0
  else
    return 1
  fi
}

###
#
# is_managed_node
#
is_managed_node() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -z "$ENDPOINT_OID" ]; then
    return 0
  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
    # found a "+" in the oid, must be a TMA endpoint!
    return 1
  else
    return 0
  fi
}

###
#
# is_OS_NT
#
is_OS_NT() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "`uname`" = "Windows_NT" ]; then
    return 0
  else
    return 1
  fi
}


###
#
#   Return value for BINDIR
#
bindir() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    OSERV=`objcall 0.0.0 get_oserv`; export OSERV
    INTERP=`objcall $OSERV query interp`; export INTERP
    inst_dir="`objcall $OSERV query install_dir`"
    bindir="$inst_dir/$INTERP"
  else
    bindir="$LCF_BINDIR/.."
  fi
  bindir="`echo $bindir | sed -e 's,\\\\,/,g'`"
  echo $bindir
}

###
#
#   Return value for INST_DIR
#
inst_dir() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    OSERV=`objcall 0.0.0 get_oserv`; export OSERV
    inst_dir="`objcall $OSERV query install_dir`"
  else
    inst_dir="$LCFROOT"
  fi
  inst_dir="`echo $inst_dir | sed -e 's,\\\\,/,g'`"
  echo $inst_dir
}

###
#
#   Return correct value for tmp directory
#
temp() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    temp=/tmp
    if is_OS_NT; then
	temp="$DBDIR/tmp"
    fi
  else
    if [ -n "$LCF_TEMPDIR" ]; then
      temp="$LCF_TEMPDIR"
    else
      temp="$LCF_DATDIR/tmp"
    fi
  fi
  if [ ! -d "$temp" ]; then
    mkdir -p "$temp"
  fi
  echo $temp
}

###
#
#    Find the Tivoli etc directory and source the right environment setup file
#
source_etc_setup_env() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    ETC=/etc/Tivoli

    # If this is NT, then the Tivoli etc directory is in a different location
    if is_OS_NT; then
       ETC=$SystemRoot/system32/drivers/etc/Tivoli
    fi

    # Look for the optional Plus override script, if not there use the standard one
    SETUP_SCRIPT=""
    if [ ! -f "$ETC/$SETUP_SCRIPT" ]; then
	SETUP_SCRIPT=setup_env.sh
    fi
    . $ETC/$SETUP_SCRIPT
  else
    # not a managed node; find the most recent lcf_env.sh and source it
    ETC=/etc/Tivoli/lcf

    # If this is NT, then the Tivoli etc directory is in a different location
    if is_OS_NT; then
       ETC=$SystemRoot/Tivoli/lcf
    fi
    SETUP_SCRIPT=lcf_env.sh
    LCF_ETC_SCRIPT=`echo \`ls -td ${ETC}/*\` | awk '{print $1}'`/$SETUP_SCRIPT
    if [ -f "$LCF_ETC_SCRIPT" ]; then
      . $LCF_ETC_SCRIPT
    fi
  fi
}

###
#
# ironame
#
ironame() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    #
    #	Get the region name to avoid collisions
    #
    iro=`wlookup InterRegion`
    ironame=`idlattr -t -g $iro name string`
    ironame=`eval echo $ironame`
    echo $ironame
  else
    echo ""
  fi
}

###
#
# mnname
#
mnname() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    mnoid=`objcall 0.0.0 get_host_location`
    eval mnname=`idlattr -t -g $mnoid label string`
    echo $mnname
  else
    echo ""
  fi
}

###
#
# source_product_info
#
source_product_info() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -d "$1" ]; then
    cd "$1"
    if [ -f PLUSproduct-info.sh ]; then
      . ./PLUSproduct-info.sh
      export WINSTRUCTED
      export MODULE_VERSION
    else
      errecho "$1/PLUSproduct-info.sh not found!"
    fi
  else
    errecho "$1/PLUSproduct-info.sh not found!"
  fi
}

###
#
# get_install_opts
#
get_install_opts() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -n "$INSTALL_OPTS" ]; then
   if [ -f "$LINKDIR/PLUSget_install_opts.sh" ]; then
	. "$LINKDIR/PLUSget_install_opts.sh"
   fi
  fi
}

###
#
# source_tws_plus_env
#
source_tws_plus_env()
{
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then

    TWS_PLUS_SCRIPT="tws_plus.sh"
    if [ -f "$ETC/$TWS_PLUS_SCRIPT" ]; then
      . $ETC/$TWS_PLUS_SCRIPT
    else
      MAESTROUSER=`wgetattr TWUSER @Presentation:"Product_Install (TWS)"`
      MAESTRODIR=`wgetattr TWSDIR @Presentation:"Product_Install (TWS)"`
      JSCONSOLEDIR=`wgetattr JSCONSOLEDIR @Presentation:"Product_Install (TWS)"`
      export MAESTROUSER MAESTRODIR JSCONSOLEDIR
    fi
  else
    TWS_PLUS_SCRIPT="tws_plus.sh"
    if [ -f "$LCF_DATDIR/$TWS_PLUS_SCRIPT" ]; then
      . "$LCF_DATDIR/$TWS_PLUS_SCRIPT"
    fi
  fi
}


####
#
# Managed node launch
#
mn_launch() {

  ARGLIST=""
  COMPONENT_NAME="Maestro"
  PRESNAME=@Presentation:"$COMPONENT_NAME"_"$MNNAME"_"$MEDIUM_PRODNAME"
  DIALOG_DESCRIPTOR="jsconsole.sh.d"

  #
  # Under Windows_NT, a GUI should be launched using the wrunui command, 
  # and only on the active desktop
  #
  if is_OS_NT ; then
    MACHINE=`echo $WD_DISPLAY | awk -F : '{print $1}'`
    if [ "$MNNAME" != "$MACHINE" ]; then
      error_msg="This task can only be run on $MNNAME from a Tivoli desktop on $MNNAME."
      wdispmsg "$error_msg"
      exit 0
    fi
    WRUNUI="$BINDIR/bin/wrunui.exe"
    if [ ! -f "$WRUNUI" ]; then
      error_msg="$WRUNUI NOT FOUND.  Please contact Tivoli Customer Support."
      wdispmsg "$error_msg"
      exit 0
    fi
  fi

  #
  # The following sets the path and display, and then allows the
  # determination of the correct binaries according to the OS type
  #
  PATH=/usr/bin:/bin:/usr/sbin:/sbin:/usr/ucb:$PATH
  DISPLAY=$WD_DISPLAY
  export PATH DISPLAY


  UNIX_OS=`uname -sr`
  case $UNIX_OS in
	Windows_NT*)
		cmd="${JSCONSOLEDIR}/bin/java/NTconsole.bat"
		;;
	"SunOS 5"*)		
		cmd="${JSCONSOLEDIR}/bin/java/SUNconsole.sh"
		;;
	AIX*)	
		cmd="${JSCONSOLEDIR}/bin/java/AIXconsole.sh"
		;;
	HP-UX*)	
		cmd="${JSCONSOLEDIR}/bin/java/HPconsole.sh"
		;;
	Linux*)	
		cmd="${JSCONSOLEDIR}/bin/java/LINUXconsole.sh"
		;;
	*)
                error_msg="Job Scheduling Console not supported on $UNIX_OS"
		wdispmsg "$error_msg"
		exit 0
		;;
  esac

  if type "$cmd" > /dev/null 2>&1; then
    cd "${JSCONSOLEDIR}/bin/java"
    if is_OS_NT; then
    	$WRUNUI "$cmd" > /dev/null 2>&1 
    else
        "$cmd" > /dev/null  2>&1
    fi
  else
    error_msg="\"$cmd\" not found in PATH."
    wdispmsg "$error_msg"
  fi
}


####
#
# LCF endpoint launch
#
lcf_ep_launch() {

  #
  # Under Windows_NT, a GUI should be launched using the wrunuiep command, 
  # and only on the active desktop
  #
  EPNAME=`echo $ENDPOINT | awk '{print $1}'`
  if is_OS_NT ; then
    MACHINE=`echo $WD_DISPLAY | awk -F : '{print $1}'`
    if [ "$EPNAME" != "$MACHINE" ]; then
      error_msg="This task can only be run on $EPNAME from a Tivoli desktop on $EPNAME."
      errecho "$error_msg"
      exit 1
    fi
    WRUNUI="$BINDIR/bin/wrunuiep.exe"
    if [ ! -f "$WRUNUI" ]; then
      error_msg="$WRUNUI NOT FOUND.  Please contact Tivoli Customer Support."
      errecho "$error_msg"
      exit 1
    fi
  fi

  #
  # The following sets the path and display, and then allows the
  # determination of the correct binaries according to the OS type
  #
  PATH=/usr/bin:/bin:/usr/sbin:/sbin:/usr/ucb:$PATH
  DISPLAY=$WD_DISPLAY
  export PATH DISPLAY

  UNIX_OS=`uname -sr`
  case $UNIX_OS in
	Windows_NT*)
		cmd="${JSCONSOLEDIR}/bin/java/NTconsole.bat"
		;;
	"SunOS 5"*)		
		cmd="${JSCONSOLEDIR}/bin/java/SUNconsole.sh"
		;;
	AIX*)	
		cmd="${JSCONSOLEDIR}/bin/java/AIXconsole.sh"
		;;
	HP-UX*)	
		cmd="${JSCONSOLEDIR}/bin/java/HPconsole.sh"
		;;
	Linux*)	
		cmd="${JSCONSOLEDIR}/bin/java/LINUXconsole.sh"
		;;
	*)
                error_msg="Job Scheduling Console not supported on $UNIX_OS"
		errecho "$error_msg"
		exit 1
		;;
  esac

  if type "$cmd" > /dev/null 2>&1; then
    cd "${JSCONSOLEDIR}/bin/java"
    if is_OS_NT; then
    	$WRUNUI "$cmd" > /dev/null 2>&1 
    else
        "$cmd" > /dev/null 2>&1
    fi
  else
    error_msg="\"$cmd\" not found in PATH."
    errecho "$error_msg"
    exit 1
  fi
}


##################################################################################
#
#
if [ -n "" ]; then
  set -x
  DEBUG=true
fi

THIS_SCRIPT="`echo $0 | sed -e 's.\\\\./.g'`"
THIS_SCRIPT=`basename "$THIS_SCRIPT"`

#
#	Set up some popular environment variables
#
source_etc_setup_env
BINDIR="`bindir`"; export BINDIR
INST_DIR="`inst_dir`"; export INST_DIR
MNNAME="`mnname`"; export MNNAME
TEMP="`temp`"; export TEMP

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts may be
#		redirected to a file in TEMP by the same name as the script.
#
DEBUGDIR="$TEMP/.plusdebug"
[ -d "$DEBUGDIR" ] \
  && exec > "$DEBUGDIR/$THIS_SCRIPT" 2>&1 && set -xv
[ -f "$DEBUGDIR" ] && set -xv
[ "$DEBUG" = true ] && set -xv

#
#	Set up variables for our basic directories, path
#
PLUSDIR="$INST_DIR/generic_unix/TME/PLUS"
LINKDIR="$PLUSDIR/LINK"
PRODDIR="$PLUSDIR/TWS"
PATH="$LINKDIR:$PRODDIR:$PATH"
export PATH

#
#	source maestro environment file, tws_plus.sh, create with configure
#       plus module task 
#
source_tws_plus_env

#
#	Now perform the correct type of launch
#
if is_managed_node; then
  mn_launch $*
else
  lcf_ep_launch $*
fi

# A non-zero exit status from a method causes an odstat error
exit 0	
