#!/bin/sh
#
# File:		maestro_create_user.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#

###
#
#   errecho
#
errecho() {
  echo "$*" >&2
}

###
#
# is_lcf_ep
#
is_lcf_ep() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "$IS_ENDPOINT" = "true" ]; then
      return 0;
  else
      return 1;
  fi
#  if [ -z "$ENDPOINT_OID" ]; then
#    return 1
#  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
#    # found a "+" in the oid, must be a TMA endpoint!
#    return 0
#  else
#    return 1
#  fi
}

###
#
# is_managed_node
#
is_managed_node() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "$IS_ENDPOINT" = "false" ]; then
      return 0;
  else
      return 1;
  fi
#  if [ -z "$ENDPOINT_OID" ]; then
#    return 0
#  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
#    # found a "+" in the oid, must be a TMA endpoint!
#    return 1
#  else
#    return 0
#  fi
}

###
#
# is_OS_NT
#
is_OS_NT() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "`uname`" = "Windows_NT" ]; then
    return 0
  else
    return 1
  fi
}


###
#
#   Return value for BINDIR
#
bindir() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    OSERV=`objcall 0.0.0 get_oserv`; export OSERV
    INTERP=`objcall $OSERV query interp`; export INTERP
    inst_dir="`objcall $OSERV query install_dir`"
    bindir="$inst_dir/$INTERP"
  else
    bindir="$LCF_BINDIR/.."
  fi
  bindir="`echo $bindir | sed -e 's,\\\\,/,g'`"
  echo $bindir
}

###
#
#   Return value for INST_DIR
#
inst_dir() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    OSERV=`objcall 0.0.0 get_oserv`; export OSERV
    inst_dir="`objcall $OSERV query install_dir`"
  else
    inst_dir="$LCFROOT"
  fi
  inst_dir="`echo $inst_dir | sed -e 's,\\\\,/,g'`"
  echo $inst_dir
}

###
#
#   Return correct value for tmp directory
#
temp() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    temp=/tmp
    if is_OS_NT; then
	temp="$DBDIR/tmp"
    fi
  else
    if [ -n "$LCF_TEMPDIR" ]; then
      temp="$LCF_TEMPDIR"
    else
      temp="$LCF_DATDIR/tmp"
    fi
  fi
  if [ ! -d "$temp" ]; then
    mkdir -p "$temp"
  fi
  echo $temp
}

###
#
#    Find the Tivoli etc directory and source the right environment setup file
#
source_etc_setup_env() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    ETC=/etc/Tivoli

    # If this is NT, then the Tivoli etc directory is in a different location
    if is_OS_NT; then
       ETC=$SystemRoot/system32/drivers/etc/Tivoli
    fi

    # Look for the optional Plus override script, if not there use the standard one
    SETUP_SCRIPT=""
    if [ ! -f "$ETC/$SETUP_SCRIPT" ]; then
	SETUP_SCRIPT=setup_env.sh
    fi
    . $ETC/$SETUP_SCRIPT
  else
    # not a managed node; find the most recent lcf_env.sh and source it
    ETC=/etc/Tivoli/lcf

    # If this is NT, then the Tivoli etc directory is in a different location
    if is_OS_NT; then
       ETC=$SystemRoot/Tivoli/lcf
    fi
    SETUP_SCRIPT=lcf_env.sh
    LCF_ETC_SCRIPT=`echo \`ls -td ${ETC}/*\` | awk '{print $1}'`/$SETUP_SCRIPT
    if [ -f "$LCF_ETC_SCRIPT" ]; then
      . $LCF_ETC_SCRIPT
    fi
  fi
}

###
#
# ironame
#
ironame() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    #
    #	Get the region name to avoid collisions
    #
    iro=`wlookup InterRegion`
    ironame=`idlattr -t -g $iro name string`
    ironame=`eval echo $ironame`
    echo $ironame
  else
    echo ""
  fi
}

###
#
# mnname
#
mnname() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    mnoid=`objcall 0.0.0 get_host_location`
    eval mnname=`idlattr -t -g $mnoid label string`
    echo $mnname
  else
    echo ""
  fi
}

###
#
# source_product_info
#
source_product_info() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -d "$1" ]; then
    cd "$1"
    if [ -f PLUSproduct-info.sh ]; then
      . ./PLUSproduct-info.sh
      export WINSTRUCTED
      export MODULE_VERSION
    else
      errecho "$1/PLUSproduct-info.sh not found!"
    fi
  else
    errecho "$1/PLUSproduct-info.sh not found!"
  fi
}

###
#
# get_install_opts
#
get_install_opts() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -n "$INSTALL_OPTS" ]; then
   if [ -f "$LINKDIR/PLUSget_install_opts.sh" ]; then
	. "$LINKDIR/PLUSget_install_opts.sh"
   fi
  fi
}

##################################################################################
#
#
if [ -n "" ]; then
  set -x
  DEBUG=true
fi

TASK_PROGPATH="`echo $0 | sed -e 's.\\\\./.g'`"
THIS_SCRIPT="maestro_create_user.sh"

#
#	Set up some popular environment variables
#
source_etc_setup_env
BINDIR="`bindir`"; export BINDIR
INST_DIR="`inst_dir`"; export INST_DIR
MNNAME="`mnname`"; export MNNAME
TEMP="`temp`"; export TEMP

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts may be
#		redirected to a file in TEMP by the same name as the script.
#
DEBUGDIR="$TEMP/.plusdebug"
[ -d "$DEBUGDIR" ] \
  && echo "*** Results redirected to $DEBUGDIR/$THIS_SCRIPT" \
  && exec > "$DEBUGDIR/$THIS_SCRIPT" 2>&1 && set -xv
[ -f "$DEBUGDIR" ] && set -xv
[ "$DEBUG" = true ] && set -xv

#
#	Set up variables for our basic directories, path
#
PLUSDIR="$INST_DIR/generic_unix/TME/PLUS"
LINKDIR="$PLUSDIR/LINK"
PRODDIR="$PLUSDIR/TWS"
PATH="$LINKDIR:$PRODDIR:$PATH"
export PATH

PATH=/bin:/usr/bin:/usr/ucb:$PATH
export PATH

#Check to see if we have the correct arguments
if [ $# -ne 4 ] ; then
	echo "Usage: $0 login-name uid gid home-dir" "$0"
	exit 1
fi

LOGIN_NAME=$1
UID_VALUE=$2
GID_VALUE=$3
HOME_DIR=$4


LOGIN_EXISTS=`grep "^$LOGIN_NAME:" /etc/passwd 2> /dev/null`

if [ ! -z "$LOGIN_EXISTS" ] ; then
	#We found a login with the desired name
	EX_LOGIN=`echo $LOGIN_EXISTS | awk -F: '{print $1}'`
	EX_PASSWD=`echo $LOGIN_EXISTS | awk -F: '{print $2}'`
	EX_UID=`echo $LOGIN_EXISTS | awk -F: '{print $3}'`
	EX_GID=`echo $LOGIN_EXISTS | awk -F: '{print $4}'`
	EX_GCOS=`echo $LOGIN_EXISTS | awk -F: '{print $5}'`
	EX_HOMEDIR=`echo $LOGIN_EXISTS | awk -F: '{print $6}'`
	EX_SHELL=`echo $LOGIN_EXISTS | awk -F: '{print $7}'`

	#We must perform several checks to see if the users would be equivalent

	#Check to see if the UIDs and GIDs are the same
	eval UID1=`echo $UID_VALUE`
	eval UID2=`echo $EX_UID`
	if [ "$UID1" != "$UID2" ] ; then
		errecho "Existing uid \"$UID2\" for user \"$LOGIN_NAME\" does not match desired uid \"$UID1\""
		exit 2
	fi

	eval GID1=`echo $GID_VALUE`
	eval GID2=`echo $EX_GID`

	if [ "$GID1" != "$GID2" ] ; then
		errecho "Existing gid \"$GID2\" for user \"$LOGIN_NAME\" does not match desired gid \"$GID1\""
		exit 3
	fi

	#Check to see if EX_HOMEDIR is the same place as HOME_DIR
	HD1=`cd $EX_HOMEDIR;/bin/pwd`
	HD2=`cd $HOME_DIR;/bin/pwd`

	if [ "$HD1" != "$HD2" ] ; then
		errecho "Existing home directory \"$HD1\" for user \"$LOGIN_NAME\" does not match desired home directory \"$HD2\""
		exit 4
	fi

	errecho "Existing user \"$LOGIN_NAME\" is configured properly"

	#Add $HOME_DIR and $HOME_DIR/bin to path

	SHELL_TYPE=`echo $EX_SHELL | awk -F/ '{print $NF}'`

	case $SHELL_TYPE in

		sh)
			if [ -f $HOME_DIR/.profile ] ; then
				echo "PATH=$HOME_DIR:$HOME_DIR/bin:"'$PATH' >> $HOME_DIR/.profile
				echo "export PATH" >> $HOME_DIR/.profile
				errecho "Configured $HOME_DIR/.profile for user \"$LOGIN_NAME\""
			else
				echo "PATH=$HOME_DIR:$HOME_DIR/bin:/bin:/usr/bin:/usr/sbin:/usr/etc:/usr/ucb" > $HOME_DIR/.profile
				echo "export PATH" >> $HOME_DIR/.profile
				errecho "Created $HOME_DIR/.profile for user \"$LOGIN_NAME\""
			fi
			;;
		csh)
			if [ -f $HOME_DIR/.cshrc ] ; then
				echo "set path = ($HOME_DIR $HOME_DIR/bin "'$path'")" >> $HOME_DIR/.cshrc
				errecho "Configured $HOME_DIR/.cshrc for user \"$LOGIN_NAME\""
			else
				echo "set path = ($HOME_DIR $HOME_DIR/bin /bin /usr/bin /usr/sbin /usr/etc /usr/ucb)" > $HOME_DIR/.cshrc
				errecho "Created $HOME_DIR/.cshrc for user \"$LOGIN_NAME\""
			fi
			;;
		ksh)
			if [ -f $HOME_DIR/.profile ] ; then
				echo "export PATH=$HOME_DIR:$HOME_DIR/bin:"'$PATH' >> $HOME_DIR/.profile
				errecho "Configured $HOME_DIR/.profile for user \"$LOGIN_NAME\""
			else
				echo "export PATH=$HOME_DIR:$HOME_DIR/bin:/bin:/usr/bin:/usr/sbin:/usr/etc:/usr/ucb" > $HOME_DIR/.profile
				errecho "Created $HOME_DIR/.profile for user \"$LOGIN_NAME\""
			fi
			;;
		*)
			errecho "Unsupported shell \"$SHELL_TYPE\", unable to add \"$HOME_DIR:$HOME_DIR/bin\" to path."
			;;
	esac
	exit 0
fi

#No user exists with this name
errecho "No user named \"$LOGIN_NAME\" found in /etc/passwd, creating user..."
#We will make the home directory and then fabricate the line in
#the passwd file

if [ ! -d $HOME_DIR ] ; then
	#Attempt to create desired directory
	DESIRED_DIR=$HOME_DIR
	CURRENT_DIR=
	INCREMENTAL=`echo $DESIRED_DIR | sed -e 's/\// /g'`
	for next_dir in $INCREMENTAL
	do
		CURRENT_DIR=$CURRENT_DIR/$next_dir
		if [ ! -d "$CURRENT_DIR" ] ; then
			mkdir $CURRENT_DIR
			if [ ! -d "$CURRENT_DIR" ] ; then
				break
			fi
		fi
	done
	if [ ! -d $DESIRED_DIR ] ; then
		#Can't make DESIRED_DIR
		errecho "Unable to create directory \"$DESIRED_DIR\""
		exit 3
	fi	
fi

chown $UID_VALUE $HOME_DIR
chgrp $GID_VALUE $HOME_DIR

#Fabricate a passwd entry

PASSWD_ENTRY="$LOGIN_NAME:x:$UID_VALUE:$GID_VALUE:Maestro User:$HOME_DIR:/bin/sh"
echo $PASSWD_ENTRY >> /etc/passwd

errecho "Successfully created user \"$LOGIN_NAME\""

if [ -f $HOME_DIR/.profile ] ; then
	echo "PATH=$HOME_DIR:$HOME_DIR/bin:"'$PATH' >> $HOME_DIR/.profile
	echo "export PATH" >> $HOME_DIR/.profile
	errecho "Configured $HOME_DIR/.profile for user \"$LOGIN_NAME\""
else
	echo "PATH=$HOME_DIR:$HOME_DIR/bin:/bin:/usr/bin:/usr/sbin:/usr/etc:/usr/ucb" > $HOME_DIR/.profile
	echo "export PATH" >> $HOME_DIR/.profile
	errecho "Created $HOME_DIR/.profile for user \"$LOGIN_NAME\""
fi

chown $UID_VALUE $HOME_DIR/.profile
chgrp $GID_VALUE $HOME_DIR/.profile

if [ -f /bin/pwconv ] ; then
	echo "Syncing /etc/passwd and /etc/shadow." >&2
	/bin/pwconv
fi

exit 0
