#!/bin/sh
#
# File:		maestro_nt_fp_post.sh
#
# Product:	Tivoli Module
# Description:	Shell Script
# Author:		Module Generator
#
# Generated:	
#
# (C) COPYRIGHT Tivoli Systems, Inc., 1997
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#

###
#
#   errecho
#
errecho() {
  echo "$*" >&2
}

###
#
# is_lcf_ep
#
is_lcf_ep() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "$IS_ENDPOINT" = "true" ]; then
      return 0;
  else
      return 1;
  fi
#  if [ -z "$ENDPOINT_OID" ]; then
#    return 1
#  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
#    # found a "+" in the oid, must be a TMA endpoint!
#    return 0
#  else
#    return 1
#  fi
}

###
#
# is_managed_node
#
is_managed_node() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "$IS_ENDPOINT" = "false" ]; then
      return 0;
  else
      return 1;
  fi
#  if [ -z "$ENDPOINT_OID" ]; then
#    return 0
#  elif echo $ENDPOINT_OID | awk -F\# '{print $1}' | grep "+$" > /dev/null; then
#    # found a "+" in the oid, must be a TMA endpoint!
#    return 1
#  else
#    return 0
#  fi
}

###
#
# is_OS_NT
#
is_OS_NT() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ "`uname`" = "Windows_NT" ]; then
    return 0
  else
    return 1
  fi
}


###
#
#   Return value for BINDIR
#
bindir() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    OSERV=`objcall 0.0.0 get_oserv`; export OSERV
    INTERP=`objcall $OSERV query interp`; export INTERP
    inst_dir="`objcall $OSERV query install_dir`"
    bindir="$inst_dir/$INTERP"
  else
    bindir="$LCF_BINDIR/.."
  fi
  bindir="`echo $bindir | sed -e 's,\\\\,/,g'`"
  echo $bindir
}

###
#
#   Return value for INST_DIR
#
inst_dir() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    OSERV=`objcall 0.0.0 get_oserv`; export OSERV
    inst_dir="`objcall $OSERV query install_dir`"
  else
    inst_dir="$LCFROOT"
  fi
  inst_dir="`echo $inst_dir | sed -e 's,\\\\,/,g'`"
  echo $inst_dir
}

###
#
#   Return correct value for tmp directory
#
temp() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    temp=/tmp
    if is_OS_NT; then
	temp="$DBDIR/tmp"
    fi
  else
    if [ -n "$LCF_TEMPDIR" ]; then
      temp="$LCF_TEMPDIR"
    else
      temp="$LCF_DATDIR/tmp"
    fi
  fi
  if [ ! -d "$temp" ]; then
    mkdir -p "$temp"
  fi
  echo $temp
}

###
#
#    Find the Tivoli etc directory and source the right environment setup file
#
source_etc_setup_env() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    ETC=/etc/Tivoli

    # If this is NT, then the Tivoli etc directory is in a different location
    if is_OS_NT; then
       ETC=$SystemRoot/system32/drivers/etc/Tivoli
    fi

    # Look for the optional Plus override script, if not there use the standard one
    SETUP_SCRIPT=""
    if [ ! -f "$ETC/$SETUP_SCRIPT" ]; then
	SETUP_SCRIPT=setup_env.sh
    fi
    . $ETC/$SETUP_SCRIPT
  else
    # not a managed node; find the most recent lcf_env.sh and source it
    ETC=/etc/Tivoli/lcf

    # If this is NT, then the Tivoli etc directory is in a different location
    if is_OS_NT; then
       ETC=$SystemRoot/Tivoli/lcf
    fi
    SETUP_SCRIPT=lcf_env.sh
    LCF_ETC_SCRIPT=`echo \`ls -td ${ETC}/*\` | awk '{print $1}'`/$SETUP_SCRIPT
    if [ -f "$LCF_ETC_SCRIPT" ]; then
      . $LCF_ETC_SCRIPT
    fi
  fi
}

###
#
# ironame
#
ironame() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    #
    #	Get the region name to avoid collisions
    #
    iro=`wlookup InterRegion`
    ironame=`idlattr -t -g $iro name string`
    ironame=`eval echo $ironame`
    echo $ironame
  else
    echo ""
  fi
}

###
#
# mnname
#
mnname() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if is_managed_node; then
    mnoid=`objcall 0.0.0 get_host_location`
    eval mnname=`idlattr -t -g $mnoid label string`
    echo $mnname
  else
    echo ""
  fi
}

###
#
# source_product_info
#
source_product_info() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -d "$1" ]; then
    cd "$1"
    if [ -f PLUSproduct-info.sh ]; then
      . ./PLUSproduct-info.sh
      export WINSTRUCTED
      export MODULE_VERSION
    else
      errecho "$1/PLUSproduct-info.sh not found!"
    fi
  else
    errecho "$1/PLUSproduct-info.sh not found!"
  fi
}

###
#
# get_install_opts
#
get_install_opts() {
  if [ "$DEBUG" = true ]; then set -x; fi
  if [ -n "$INSTALL_OPTS" ]; then
   if [ -f "$LINKDIR/PLUSget_install_opts.sh" ]; then
	. "$LINKDIR/PLUSget_install_opts.sh"
   fi
  fi
}

##################################################################################
#
#
if [ -n "" ]; then
  set -x
  DEBUG=true
fi

TASK_PROGPATH="`echo $0 | sed -e 's.\\\\./.g'`"
THIS_SCRIPT="maestro_nt_fp_post.sh"

#
#	Set up some popular environment variables
#
source_etc_setup_env
BINDIR="`bindir`"; export BINDIR
INST_DIR="`inst_dir`"; export INST_DIR
MNNAME="`mnname`"; export MNNAME
TEMP="`temp`"; export TEMP

#
#	Debugging code: by creating a directory called .plusdebug in
#		the appropriate TEMP directory, the output of scripts may be
#		redirected to a file in TEMP by the same name as the script.
#
DEBUGDIR="$TEMP/.plusdebug"
[ -d "$DEBUGDIR" ] \
  && echo "*** Results redirected to $DEBUGDIR/$THIS_SCRIPT" \
  && exec > "$DEBUGDIR/$THIS_SCRIPT" 2>&1 && set -xv
[ -f "$DEBUGDIR" ] && set -xv
[ "$DEBUG" = true ] && set -xv

#
#	Set up variables for our basic directories, path
#
PLUSDIR="$INST_DIR/generic_unix/TME/PLUS"
LINKDIR="$PLUSDIR/LINK"
PRODDIR="$PLUSDIR/TWS"
PATH="$LINKDIR:$PRODDIR:$PATH"
export PATH

NODENAME=`uname -n | tr [A-Z] [a-z]`
export NODENAME

NESTED_SRC_DIR=/temp/.maestro_tme
PATH=${NESTED_SRC_DIR}:${PATH}
export PATH

if [ -z "$IS_ENDPOINT" ] ; then
	errecho "Must set IS_ENDPOINT environment variable"
	exit 1
fi

if [ -z "$MAESTRO_DIR" ] ; then
	errecho "Must set MAESTRO_DIR environment variable"
	exit 1
fi

PATH=${MAESTRO_DIR}/MAESTRO:${MAESTRO_DIR}/MAESTRO/bin:${PATH}
export PATH

if [ -z "$ISS_FILE" ] ; then
	errecho "Must set ISS_FILE environment variable"
	exit 1
fi

ISS_NAME_ONLY=`echo $ISS_FILE | awk -F/ '{print $NF}'`

if [ ! -f ${NESTED_SRC_DIR}/$ISS_NAME_ONLY ] ; then
	errecho "Could not find the response file named \"${NESTED_SRC_DIR}/$ISS_NAME_ONLY\""
	exit 2
fi

if [ -z "$MAP_FILE" ] ; then
	errecho "Must set MAP_FILE environment variable"
	exit 1
fi

MAP_NAME_ONLY=`echo $MAP_FILE | awk -F/ '{print $NF}'`

if [ ! -f ${NESTED_SRC_DIR}/$MAP_NAME_ONLY ] ; then
	errecho "Could not find the TWS cpu map file named \"${NESTED_SRC_DIR}/$MAP_NAME_ONLY\""
	exit 2
fi


HAS_KEY=`grep "^$NODENAME:" ${NESTED_SRC_DIR}/$MAP_NAME_ONLY`

if [ -z "$HAS_KEY" ] ; then
	errecho "There is no entry for node \"$NODENAME\" in the TWS cpu map file \"${NESTED_SRC_DIR}/$MAP_NAME_ONLY\""
	exit 3
fi

#We found a map entry with the desired name
NODENAME=`echo $HAS_KEY | awk -F: '{print $1}'`
THIS_CPUNAME=`echo $HAS_KEY | awk -F: '{print $2}'`
CPU_TYPE=`echo $HAS_KEY | awk -F: '{print $3}'`
MASTER_MNNAME=`echo $HAS_KEY | awk -F: '{print $4}'`
MASTER_CPUNAME=`echo $HAS_KEY | awk -F: '{print $5}'`

#Check to see if the fields are all set correctly

#Check THIS_CPUNAME
if [ -z "$THIS_CPUNAME" ] ; then
	errecho "Must have a cpuname for node \"$NODENAME\" in the TWS cpu map file for this file package"
	exit 4
fi


#Check to see if the value for CPU_TYPE is a known type before attempting
#the customize script

case "$CPU_TYPE" in
	master)
		if [ x"$MASTER_MNNAME" = x ] ; then
			MASTER_MNNAME="$NODENAME"
			MASTER_CPUNAME="$THIS_CPUNAME"
		fi

		if [ x"$NODENAME" != x"$MASTER_MNNAME" ] ; then
			errecho "node \"$NODENAME\" and master_node \"$MASTER_MNNAME\" must match in order to install this host as a TWS master"
			exit 15
		fi

		if [ x"$THIS_CPUNAME" != x"$MASTER_CPUNAME" ] ; then
			errecho "cpuname \"$THIS_CPUNAME\" and master_cpuname \"$MASTER_CPUNAME\" must match in order to install this cpu as a TWS master"
			exit 20
		fi
		;;
	fta)
		;;
	sagent)
		;;
	backup)
		;;
	*)
		errecho "Invalid type \"$CPU_TYPE\" specified for cpu name \"$THIS_CPUNAME\". Valid types are master, fta, sagent, backup"
		exit 10
		;;
esac

if [ -z "$MASTER_MNNAME" ] ; then 
	errecho "Must supply a master_node name for node \"$NODENAME\" in TWS cpu map file"
	exit 12
fi

if [ -z "$MASTER_CPUNAME" ] ; then 
	errecho "Must supply a master_cpuname for node \"$NODENAME\" in TWS cpu map file"
	exit 14
fi

#
# determine if this is an update installation.
#
headings=`grep -n "^[[]" ${NESTED_SRC_DIR}/$ISS_NAME_ONLY | cut -d: -f1`
start=`grep -n "^[[]" ${NESTED_SRC_DIR}/$ISS_NAME_ONLY | grep AskOptions-0 | cut -d: -f1`
end=0
next=0
for h in $headings
do
	if [ $h -eq $start ] ; then
		next=1 	
	else
		if [ $next -eq 1 ]; then
		 	end=$h
			break
		fi
	fi
done
INSTALL_TYPE=`sed -n -e "${start},${end}p" ${NESTED_SRC_DIR}/$ISS_NAME_ONLY | grep Sel-0 | awk -F= '{print $2}'`

#
# Substitute ThisCPU and MasterCPU (should be present only on new *.iss file)
#
sed -e  "s|ThisCPU=[A-Z,a-z,(,)]*|ThisCPU=$THIS_CPUNAME|
         s|MasterCPU=[A-Z,a-z,(,)]*|MasterCPU=$MASTER_CPUNAME|" ${NESTED_SRC_DIR}/$ISS_NAME_ONLY > ${NESTED_SRC_DIR}/maestro.iss.temp

if [ -z "$USERNAME" ] ; then
	USERNAME=`${NESTED_SRC_DIR}/tmuid.exe`
	export USERNAME
fi

if [ -z "$COMPUTERNAME" ] ; then
	COMPUTERNAME=`uname -n`
	export COMPUTERNAME
fi

cd $MAESTRO_DIR/MAESTRO
mv ${NESTED_SRC_DIR}/maestro.iss.temp ${MAESTRO_DIR}/MAESTRO/maestro.iss

${MAESTRO_DIR}/MAESTRO/setup.exe -s -SMS -f1${MAESTRO_DIR}/MAESTRO/maestro.iss -f2${MAESTRO_DIR}/MAESTRO/setup.log
RESULT=`grep ResultCode ${MAESTRO_DIR}/MAESTRO/setup.log | grep =0`

rm -f ${MAESTRO_DIR}/MAESTRO/maestro.iss

if [ -z $RESULT ] ; then
	errecho "TWS install failed. See file $MAESTRO_DIR/MAESTRO/setup.log file."
	exit 2
fi


#
# add cpus on new installation 
#
if [ "$INSTALL_TYPE" -eq 1 ]; then
    if is_managed_node; then

	if [ "$CPU_TYPE" != "master" ] ; then

        	IS_MASTER_ENDPOINT=true
        	wlookup -r ManagedNode $MASTER_NODENAME > /dev/null 2>&1
        	if [ $? -eq 0 ]; then
            		IS_MASTER_ENDPOINT=false
        	fi

		echo Adding the necessary cpu definition on master cpu >&2
		if [ "$CPU_TYPE" != "sagent" ] ; then
			#Add local cpu to the maestro master
			wruntask -t "TWS_Add_CPU" -l "Hidden Sentry Tasks for TWS"  -h "$MASTER_MNNAME" -a "$IS_MASTER_ENDPOINT" -a "$THIS_CPUNAME" -a "$NODENAME" -a wnt -a "$CPU_TYPE" -o 15 > $TEMP/maestro_add_cpu.out 2>&1
	 	else
			#Add local cpu to the maestro master
			wruntask -t "TWS_Add_CPU" -l "Hidden Sentry Tasks for TWS"  -h "$MASTER_MNNAME" -a "$IS_MASTER_ENDPOINT" -a "$THIS_CPUNAME" -a "$NODENAME" -a wnt -a "$CPU_TYPE" -a "$MASTER_CPUNAME" -o 15 > $TEMP/maestro_add_cpu.out 2>&1
		fi
	fi
    fi
fi

echo "TWS successfully installed"
exit 0

